summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
authorjbj <devnull@localhost>2002-01-06 02:23:33 +0000
committerjbj <devnull@localhost>2002-01-06 02:23:33 +0000
commit350d7592de623c3c236e45c103981d1e55f5e5d4 (patch)
tree565f2d460330cf04d8345eaed599dee0e00b7c70 /lib
parentcd622ba0de30cdd85658bb2fe007c5ed02e89e23 (diff)
downloadlibrpm-tizen-350d7592de623c3c236e45c103981d1e55f5e5d4.tar.gz
librpm-tizen-350d7592de623c3c236e45c103981d1e55f5e5d4.tar.bz2
librpm-tizen-350d7592de623c3c236e45c103981d1e55f5e5d4.zip
- sparc: make dbenv per-rpmdb, not per-dbi.
CVS patchset: 5237 CVS date: 2002/01/06 02:23:33
Diffstat (limited to 'lib')
-rw-r--r--lib/depends.c2
-rw-r--r--lib/rpmte.c4
-rw-r--r--lib/rpmte.h6
3 files changed, 9 insertions, 3 deletions
diff --git a/lib/depends.c b/lib/depends.c
index 2ee2ab220..79cf7feb6 100644
--- a/lib/depends.c
+++ b/lib/depends.c
@@ -1698,7 +1698,7 @@ assert(newOrderCount == ts->orderCount);
ts->orderAlloced = ts->orderCount;
orderList = _free(orderList);
-#ifdef HACK
+#if defined(__LCLINT__) /* XXX HACK rpmsort needs for graphviz */
/* Clean up after dependency checks */
pi = teInitIterator(ts);
while ((p = teNextIterator(pi)) != NULL) {
diff --git a/lib/rpmte.c b/lib/rpmte.c
index 9ebfe7f45..de23243f3 100644
--- a/lib/rpmte.c
+++ b/lib/rpmte.c
@@ -267,10 +267,14 @@ transactionElement teGetParent(transactionElement te)
transactionElement teSetParent(transactionElement te, transactionElement pte)
{
transactionElement opte = NULL;
+ /*@-branchstate@*/
if (te != NULL) {
opte = te->parent;
+ /*@-assignexpose -temptrans@*/
te->parent = pte;
+ /*@=assignexpose =temptrans@*/
}
+ /*@=branchstate@*/
return opte;
}
diff --git a/lib/rpmte.h b/lib/rpmte.h
index ecd45001b..16b4dc448 100644
--- a/lib/rpmte.h
+++ b/lib/rpmte.h
@@ -290,6 +290,7 @@ int teSetTree(transactionElement te, int ntree)
* @param te transaction element
* @return parent transaction element
*/
+/*@observer@*/ /*@unused@*/
transactionElement teGetParent(transactionElement te)
/*@*/;
@@ -313,10 +314,10 @@ int teGetDegree(transactionElement te)
/**
* Set number of children of transaction element.
* @param te transaction element
* @param ntree new number of children
* @return previous number of children
*/
-int teSetDegree(transactionElement te, int ntree)
+int teSetDegree(transactionElement te, int ndegree)
/*@modifies te @*/;
/**
@@ -345,6 +346,7 @@ void teNewTSI(transactionElement te)
* Destroy dependency set info of transaction element.
* @param te transaction element
*/
+/*@unused@*/
void teCleanDS(transactionElement te)
/*@modifies te @*/;
@@ -313,10 +314,10 @@ int teGetDegree(transactionElement te)
* Set number of children of transaction element.
* @param te transaction element
- * @param ntree new number of children
+ * @param ndegree new number of children
* @return previous number of children
*/